@@ -44,12 +44,12 @@ class ContextBuilder(object):
     def from_http_request(request):
         try:
             client_token = request.cookies[RequestUtils.SECURENATIVE_COOKIE]
-        except AttributeError:
+        except Exception:
             client_token = None
 
         try:
             headers = request.headers
-        except AttributeError:
+        except Exception:
             headers = None
 
         if Utils.is_null_or_empty(client_token):
